@@ -1,7 +1,5 @@
 package Hash::AutoHash::Record;
-our $VERSION='1.17_01';
-$VERSION=eval $VERSION;		# I think this is the accepted idiom..
-
+our $VERSION='1.10';
 #################################################################################
 #
 # Author:  Nat Goodman
@@ -27,7 +25,6 @@ our @SUBCLASS_EXPORT_OK=$helper_class->SUBCLASS_EXPORT_OK;
 # functions herein (except _new) are exportable by Hash::AutoHash::Args
 #################################################################################
 package Hash::AutoHash::Record::helper;
-our $VERSION=$Hash::AutoHash::Record::VERSION;
 use strict;
 use Carp;
 BEGIN {
@@ -50,7 +47,7 @@ sub autohash_clear {
 # Tied hash which implements Hash::AutoHash::Record
 #################################################################################
 package Hash::AutoHash::Record::tie;
-our $VERSION=$Hash::AutoHash::Record::VERSION;
+our $VERSION='1.10';
 use strict;
 use Carp;
 use Tie::Hash;
@@ -324,7 +321,7 @@ Hash::AutoHash::Record - Object-oriented access to hash with implicitly typed fi
 
 =head1 VERSION
 
-Version 1.17
+Version 1.10
 
 =head1 SYNOPSIS
 
@@ -546,14 +543,6 @@ individual objects), functions that must be imported into the caller's
 namespace, and methods invoked on the tied object implementing the
 hash.
 
-CAUTION: As of version 1.12, it is not possible to use method
-notation for keys with the same names as methods inherited from
-UNIVERSAL (the base class of everything). These are 'can', 'isa',
-'DOES', and 'VERSION'.  The reason is that as of Perl 5.9.3, calling
-UNIVERSAL methods as functions is deprecated and developers are
-encouraged to use method form instead. Previous versions of AutoHash
-are incompatible with CPAN modules that adopt this style.
-
 =head2 Field-types
 
 The type of a field is determined implicitly by its value.  When you
@@ -809,9 +798,9 @@ You can do the same thing more concisely with this cryptic one-liner.
 
 Filtering occurs when you run the 'filter' method. It does not occur on every update.
 
-=head2 new
+=head2 Functions and methods
 
-'new' is the constructor.
+The constructor is 'new'.
 
  Title   : new 
  Usage   : $record=new Hash::AutoHash::Record
@@ -822,9 +811,8 @@ Filtering occurs when you run the 'filter' method. It does not occur on every up
  Args    : Optional list of key=>value pairs which are used to set initial
            values, types, and defaults for each field of the object.
 
-=head2 defaults
-
-This method must be invoked on the B<tied object implementing the hash>.
+The next three methods must be invoked on the B<tied object
+implementing the hash>.
 
  Title   : defaults 
  Usage   : %defaults=tied(%$record)->defaults
@@ -857,10 +845,6 @@ This method must be invoked on the B<tied object implementing the hash>.
  Returns : defaults as a list or ARRAY depending on context 
  Args    : key=>value pairs.
 
-=head2 force
-
-This method must be invoked on the B<tied object implementing the hash>.
-
  Title   : force 
  Usage   : tied(%$record)->force('favorites',{colors=>['red','blue'])
            -- OR --
@@ -874,9 +858,6 @@ This method must be invoked on the B<tied object implementing the hash>.
  Returns : new value, if any, or undef 
  Args    : key and optional new value
 
-=head2 unique
-
-This method must be invoked on the B<tied object implementing the hash>.
 
  Title   : unique 
  Usage   : $unique=tied(%$record)->unique
@@ -913,10 +894,6 @@ This method must be invoked on the B<tied object implementing the hash>.
            occurs on every update including when default values are restored by 
            clearing the object.
 
-=head2 filter
-
-This method must be invoked on the B<tied object implementing the hash>.
-
  Title   : filter 
  Usage   : $filter=tied(%$record)->filter
            -- OR --
@@ -950,8 +927,6 @@ Function:  Set function used for filtering and perform filtering if true.
            filtering occurs immediately by running all existing elements through
            the filter function.
 
-=head2 Functions inherited from Hash::AutoHash
-
 The following functions are inherited from L<Hash::AutoHash> and,
 except for autohash_clear, operate exactly as there. You must import
 them into your namespace before use.
@@ -962,8 +937,6 @@ them into your namespace before use.
        autohash_keys autohash_values 
        autohash_count autohash_empty autohash_notempty)
 
-=head3 autohash_alias
-
 Aliasing a Hash::AutoHash object to a regular hash avoids the need to
 dereference the variable when using hash notation.  As a convenience,
 the autoahash_alias functions can link in either direction depending
@@ -975,8 +948,6 @@ on whether the given object exists.
  Args    : Hash::AutoHash::Record object and hash 
  Returns : Hash::AutoHash::Record object
 
-=head3 autohash_tied
-
 You can access the object implementing the tied hash using Perl's
 built-in tied function or the autohash_tied function inherited from
 L<Hash::AutoHash>.  Advantages of autohash_tied are (1) it operates
@@ -1008,7 +979,7 @@ invoking methods on the tied object.
            Form 4. hash to which Hash::AutoHash::Record object is aliased, 
              method name, optional list of parameters for method
 
-=head3 autohash_get
+The next two functions provide wholesale manipulation of arguments.
 
  Title   : autohash_get
  Usage   : ($name,$hobbies)=autohash_get($record,qw(name hobbies))
@@ -1016,8 +987,6 @@ invoking methods on the tied object.
  Args    : Hash::AutoHash::Record object and list of keys
  Returns : list of argument values
 
-=head3 autohash_set
-
  Title   : autohash_set
  Usage   : autohash_set($record,name=>'Joe Plumber',first_name=>'Joe')
            -- OR --
@@ -1027,14 +996,10 @@ invoking methods on the tied object.
            Form 2. Hash::AutoHash::Record object, ARRAY of keys, ARRAY of values
  Returns : Hash::AutoHash::Record object
 
-=head3 Functions for hash-like operations
-
 The remaining functions provide hash-like operations on
 Hash::AutoHash::Record objects. These are useful if you want to
 avoid hash notation all together.
 
-=head4 autohash_clear
-
  Title   : autohash_clear
  Usage   : autohash_clear($record,@keys)
  Function: Delete entire contents of $record or specified keys. Restore default
@@ -1043,24 +1008,18 @@ avoid hash notation all together.
  Args    : Hash::AutoHash::Record object, optional list of keys
  Returns : nothing
 
-=head4 autohash_delete
-
  Title   : autohash_delete
  Usage   : autohash_delete($record,@keys)
  Function: Delete keys and their values from $record.
  Args    : Hash::AutoHash::Record object, list of keys
  Returns : nothing
 
-=head4 autohash_exists
-
  Title   : autohash_exists
  Usage   : if (autohash_exists($record,$key)) { ... }
  Function: Test whether key is present in $record.
  Args    : Hash::AutoHash::Record object, key
  Returns : boolean
 
-=head4 autohash_each
-
  Title   : autohash_each
  Usage   : while (my($key,$value)=autohash_each($record)) { ... }
            -- OR --
@@ -1070,40 +1029,30 @@ avoid hash notation all together.
  Returns : list context: next key=>value pair in $record or empty list at end
            scalar context: next key in $record or undef at end
 
-=head4 autohash_keys
-
  Title   : autohash_keys
  Usage   : @keys=autohash_keys($record)
  Function: Get all keys that are present in $record
  Args    : Hash::AutoHash::Record object
  Returns : list of keys
 
-=head4 autohash_values
-
  Title   : autohash_values
  Usage   : @values=autohash_values($record)
  Function: Get the values of all keys that are present in $record
  Args    : Hash::AutoHash::Record object
  Returns : list of values
 
-=head4 autohash_count
-
  Title   : autohash_count
  Usage   : $count=autohash_count($record)
  Function: Get the number keys that are present in $record
  Args    : Hash::AutoHash::Record object
  Returns : number
 
-=head4 autohash_empty
-
  Title   : autohash_empty
  Usage   : if (autohash_empty($record)) { ... }
  Function: Test whether $record is empty
  Args    : Hash::AutoHash::Record object
  Returns : boolean
 
-=head4 autohash_notempty
-
  Title   : autohash_notempty
  Usage   : if (autohash_notempty($record)) { ... }
  Function: Test whether $record is not empty. Complement of autohash_empty
